@@ -7,7 +7,7 @@ from praw.models import (Comment, ModAction, ModmailAction,
                          ModmailConversation, ModmailMessage, Redditor,
                          Submission, Subreddit, SubredditMessage, Stylesheet,
                          WikiPage)
-from prawcore import Forbidden, NotFound, TooLarge
+from prawcore import Forbidden, NotFound, RequestException, TooLarge
 import mock
 import pytest
 
@@ -103,32 +103,6 @@ class TestSubreddit(IntegrationTest):
                                          syntax='cloudsearch'):
                 assert isinstance(item, Submission)
 
-    @mock.patch('time.sleep', return_value=None)
-    @mock.patch('time.time', return_value=1474803456.4)
-    def test_submissions__with_default_arguments(self, _, __):
-        with self.recorder.use_cassette(
-                'TestSubreddit.test_submissions__with_default_arguments'):
-            subreddit = self.reddit.subreddit(
-                pytest.placeholders.test_subreddit)
-            count = 0
-            for submission in subreddit.submissions():
-                count += 1
-        assert count > 1000
-
-    @mock.patch('time.sleep', return_value=None)
-    def test_submissions__with_provided_arguments(self, _):
-        with self.recorder.use_cassette(
-                'TestSubreddit.test_submissions__with_provided_arguments'):
-            subreddit = self.reddit.subreddit(
-                pytest.placeholders.test_subreddit)
-            count = 0
-            for submission in subreddit.submissions(
-                    1410000000.1, 1420000000.9,
-                    "(not author:'{}')".format(self.reddit.config.username)):
-                count += 1
-                assert submission.author != self.reddit.config.username
-        assert count > 0
-
     @mock.patch('time.sleep', return_value=None)
     def test_submit__flair(self, _):
         flair_id = '17bf09c4-520c-11e7-8073-0ef8adb5ef68'
@@ -244,6 +218,13 @@ class TestSubredditFilters(IntegrationTest):
         with self.recorder.use_cassette('TestSubredditFilters.test_add'):
             self.reddit.subreddit('all').filters.add('redditdev')
 
+    @mock.patch('time.sleep', return_value=None)
+    def test_add__subreddit_model(self, _):
+        self.reddit.read_only = False
+        with self.recorder.use_cassette('TestSubredditFilters.test_add'):
+            self.reddit.subreddit('all').filters.add(
+                self.reddit.subreddit('redditdev'))
+
     @mock.patch('time.sleep', return_value=None)
     def test_add__non_special(self, _):
         self.reddit.read_only = False
@@ -258,6 +239,13 @@ class TestSubredditFilters(IntegrationTest):
         with self.recorder.use_cassette('TestSubredditFilters.test_remove'):
             self.reddit.subreddit('mod').filters.remove('redditdev')
 
+    @mock.patch('time.sleep', return_value=None)
+    def test_remove__subreddit_model(self, _):
+        self.reddit.read_only = False
+        with self.recorder.use_cassette('TestSubredditFilters.test_remove'):
+            self.reddit.subreddit('mod').filters.remove(
+                self.reddit.subreddit('redditdev'))
+
     @mock.patch('time.sleep', return_value=None)
     def test_remove__non_special(self, _):
         self.reddit.read_only = False
@@ -997,6 +985,21 @@ class TestSubredditStreams(IntegrationTest):
             assert comment_count == 17
             assert pause_count == 2
 
+    @mock.patch('time.sleep', return_value=None)
+    def test_comments__with_skip_existing(self, _):
+        with self.recorder.use_cassette('TestSubredditStreams.comments'):
+            generator = self.reddit.subreddit('all').stream.comments(
+                skip_existing=True)
+            count = 0
+            try:
+                for comment in generator:
+                    count += 1
+            except RequestException:
+                pass
+            # This test uses the same cassette as test_comments which shows
+            # that there are at least 400 comments in the stream.
+            assert count < 400
+
     def test_submissions(self):
         with self.recorder.use_cassette('TestSubredditStreams.submissions'):
             generator = self.reddit.subreddit('all').stream.submissions()
@@ -1015,6 +1018,20 @@ class TestSubredditStreams(IntegrationTest):
                 submission = next(generator)
             assert submission_count == 100
 
+    @mock.patch('time.sleep', return_value=None)
+    def test_submissions__with_pause_and_skip_after(self, _):
+        with self.recorder.use_cassette('TestSubredditStreams.submissions'):
+            generator = self.reddit.subreddit('all').stream.submissions(
+                pause_after=-1, skip_existing=True)
+            submission = next(generator)
+            assert submission is None  # The first thing yielded should be None
+            submission_count = 0
+            submission = next(generator)
+            while submission is not None:
+                submission_count += 1
+                submission = next(generator)
+            assert submission_count < 100
+
 
 class TestSubredditStylesheet(IntegrationTest):
     @staticmethod
